:orphan:

Explanations
============

Explanation of how the library works and why it works that way.

.. toctree::
    :caption: Explanations

    explanations/uncertainty-propagation
    explanations/comparison